# -*- coding: utf-8 -*-

##############################################################################
#
# ScoDoc
#
# Copyright (c) 1999 - 2023 Emmanuel Viennet.  All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#   Emmanuel Viennet      emmanuel.viennet@viennet.net
#
##############################################################################

"""
Formulaire ajout d'une "assiduité" sur un étudiant
"""

from flask_wtf import FlaskForm
from wtforms import (
    SelectField,
    StringField,
    SubmitField,
    RadioField,
    TextAreaField,
    validators,
)


class AjoutAssiduiteEtudForm(FlaskForm):
    "Formulaire de saisie d'une assiduité pour un étudiant"
    error_message = ""  # used to report our errors

    assi_etat = RadioField(
        "Signaler:",
        choices=[("absent", "absence"), ("retard", "retard"), ("present", "présence")],
        default="absent",
        validators=[
            validators.DataRequired("spécifiez le type d'évènement à signaler"),
        ],
    )
    date_debut = StringField(
        "Date de début",
        validators=[validators.Length(max=10)],
        render_kw={
            "class": "datepicker",
            "size": 10,
            "id": "assi_date_debut",
        },
    )
    heure_debut = StringField(
        "Heure début",
        default="",
        validators=[validators.Length(max=5)],
        render_kw={
            "class": "timepicker",
            "size": 5,
            "id": "assi_heure_debut",
        },
    )
    heure_fin = StringField(
        "Heure fin",
        default="",
        validators=[validators.Length(max=5)],
        render_kw={
            "class": "timepicker",
            "size": 5,
            "id": "assi_heure_fin",
        },
    )
    date_fin = StringField(
        "Date de fin (si plusieurs jours)",
        validators=[validators.Length(max=10)],
        render_kw={
            "class": "datepicker",
            "size": 10,
            "id": "assi_date_fin",
        },
    )
    modimpl = SelectField(
        "Module",
        choices={},  # will be populated dynamically
    )
    assi_raison = TextAreaField(
        "Raison",
        render_kw={
            # "name": "assi_raison",
            "id": "assi_raison",
            "cols": 75,
            "rows": 4,
            "maxlength": 500,
        },
    )
    entry_date = StringField(
        "Date de dépot ou saisie",
        validators=[validators.Length(max=10)],
        render_kw={
            "class": "datepicker",
            "size": 10,
            "id": "entry_date",
        },
    )
    submit = SubmitField("Enregistrer")
    cancel = SubmitField("Annuler", render_kw={"formnovalidate": True})
